package repositorios;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Vector;
import conexao.Conexao;
import basicas.Despesa;

public class RepositorioDespesa {

	public RepositorioDespesa() {

	}

	/**MTODO PARA INSERIR UMA DESPESA**/

	public boolean inserirDespesa(Despesa despesa){

		boolean retorno = false;

		Conexao c = new Conexao();
		Connection conn = c.conectarBD();

		String comando = "INSERT INTO Despesa VALUES(?, ?, ?, ?, ?, ?)";

		try {

			PreparedStatement ps = conn.prepareStatement(comando);

			ps.setString(1, null);
			ps.setString(2, despesa.getCpf_atendente());
			ps.setString(3, despesa.getDataVencimento());
			ps.setString(4, despesa.getDataPagamento());
			ps.setFloat(5, despesa.getValor());
			ps.setString(6, despesa.getEmpresaBeneficiada());

			ps.execute();
			ps.close();

			c.fecharConexao();

			retorno = true;

		} catch (SQLException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return retorno;
	}

	/**MTODO PARA ATUALIZAR UMA DESPESA**/

	public void atualizarDespesa(int cod_despesa, Despesa despesa){

		Conexao c = new Conexao();
		Connection conn = c.conectarBD();

		String comando = "UPDATE Despesa SET data_vencimento = ? WHERE cod_despesa = ?";
		String comando2 = "UPDATE Despesa SET data_pagamento = ? WHERE cod_despesa = ?";
		String comando3 = "UPDATE Despesa SET valor = ? WHERE cod_despesa = ?";
		String comando4 = "UPDATE Despesa SET descricao = ? WHERE cod_despesa = ?";

		try {

			PreparedStatement ps = conn.prepareStatement(comando);
			PreparedStatement ps2 = conn.prepareStatement(comando2);
			PreparedStatement ps3 = conn.prepareStatement(comando3);
			PreparedStatement ps4 = conn.prepareStatement(comando4);

			ps.setString(1, despesa.getDataVencimento());
			ps.setInt(2, cod_despesa);

			ps2.setString(1, despesa.getDataPagamento());
			ps2.setInt(2, cod_despesa);

			ps3.setFloat(1, despesa.getValor());
			ps3.setInt(2, cod_despesa);

			ps4.setString(1, despesa.getEmpresaBeneficiada());
			ps4.setInt(2, cod_despesa);

			ps.execute();
			ps2.execute();
			ps3.execute();
			ps4.execute();

			ps.close();
			ps2.close();
			ps3.close();
			ps4.close();

			c.fecharConexao();
			
		} catch (SQLException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}	

	/**MTODO PARA REMOVER UMA DESPESA**/

	public boolean removerDespesa(int cod_despesa){

		boolean retorno = false;

		Conexao c = new Conexao(); 
		Connection conn = c.conectarBD();

		String comando = "DELETE FROM Despesa WHERE cod_despesa = ?";

		try {

			PreparedStatement ps = conn.prepareStatement(comando);

			ps.setInt(1, cod_despesa);

			ps.execute();

			ps.close();

			c.fecharConexao();

			retorno = true;

		} catch (SQLException e) {
			e.printStackTrace();
		}

		return retorno;
	}


	/**MTODO PARA CONSULTAR DESPESA**/

	public Vector<Despesa> consultarDespesaPorDataVencimento(String dataVencimento){

		Vector<Despesa> retorno = new Vector<Despesa>();
		Despesa despesa;
		Conexao c = new Conexao();
		Connection conn = c.conectarBD();

		String comando = "SELECT * FROM Despesa WHERE data_vencimento = ? ORDER BY data_vencimento";

		try {

			PreparedStatement ps = conn.prepareStatement(comando);

			ps.setString(1, dataVencimento);

			ResultSet rs = ps.executeQuery();

			while(rs.next()){

				despesa = new Despesa(rs.getString(1), rs.getString(2), rs.getString(3), rs.getString(4), rs.getFloat(5), rs.getString(6));

				retorno.add(despesa);			

			}			

			ps.close();

			rs.close();

			c.fecharConexao();

		} catch (SQLException e) {
			e.printStackTrace();
		}

		return retorno;
	}

	public Vector<Despesa> consultarDespesaPorEmpresa(String empresaBeneficiada){

		Vector<Despesa> retorno = new Vector<Despesa>();
		Despesa despesa;
		Conexao c = new Conexao();
		Connection conn = c.conectarBD();

		String comando = "SELECT * FROM Despesa WHERE descricao = ? ORDER BY descricao";

		try {

			PreparedStatement ps = conn.prepareStatement(comando);

			ps.setString(1, empresaBeneficiada);

			ResultSet rs = ps.executeQuery();

			while(rs.next()){

				despesa = new Despesa(rs.getString(1), rs.getString(2), rs.getString(3), rs.getString(4), rs.getFloat(5), rs.getString(6));

				retorno.add(despesa);			

			}			

			ps.close();

			rs.close();

			c.fecharConexao();

		} catch (SQLException e) {
			e.printStackTrace();
		}

		return retorno;

	}

	public Vector<Despesa> consultarDespesaPorStatus(String status){

		Vector<Despesa> retorno = new Vector<Despesa>();
		Despesa despesa;
		String comando;
		Conexao c = new Conexao();
		Connection conn = c.conectarBD();


		if(status.equalsIgnoreCase("sim")){

			comando = "SELECT * FROM Despesa WHERE data_pagamento <> '' ORDER BY data_pagamento";

		}else{

			comando = "SELECT * FROM Despesa WHERE data_pagamento = '' ORDER BY data_pagamento";	
		}

		try {

			PreparedStatement ps = conn.prepareStatement(comando);

			ResultSet rs = ps.executeQuery();

			while(rs.next()){

				despesa = new Despesa(rs.getString(1), rs.getString(2), rs.getString(3), rs.getString(4), rs.getFloat(5), rs.getString(6));

				retorno.add(despesa);			

			}			

			ps.close();

			rs.close();

			c.fecharConexao();

		} catch (SQLException e) {
			e.printStackTrace();
		}

		return retorno;

	}
	
	public Vector<Despesa> gerarRelatorioDespesas(){

		Vector<Despesa> retorno = new Vector<Despesa>();
		Despesa despesa = null;;
		String comando = "";
		Conexao c = new Conexao();
		Connection conn = c.conectarBD();

		comando = "SELECT * FROM Despesa ORDER BY data_pagamento";

		try {

			PreparedStatement ps = conn.prepareStatement(comando);

			ResultSet rs = ps.executeQuery();

			while(rs.next()){

				despesa = new Despesa(rs.getString(1), rs.getString(2), rs.getString(3), rs.getString(4), rs.getFloat(5), rs.getString(6));

				retorno.add(despesa);			

			}			

			ps.close();

			rs.close();

			c.fecharConexao();

		} catch (SQLException e) {
			e.printStackTrace();
		}

		return retorno;

	}


	/*public static void main(String[] args) {

		Despesa d = new Despesa(1,"07266998845", "10072010", "", (float) 5000.99, "TEATRO UFPE");
		Despesa d2 = new Despesa(2,"07266998845", "10072010", "", (float) 50.89, "CELPE");
		Despesa d3 = new Despesa(3,"07266998845", "11082010", "", (float) 88.89, "COMPESA");

		RepositorioDespesa r = new RepositorioDespesa();

		//r.inserirDespesa(d);
		//r.inserirDespesa(d2);
		//r.inserirDespesa(d3);

		//r.atualizarDespesa(1, new Despesa(-1,"","11072010","11072010",(float)4900.99,"Centro de Convenes da UFPE"));
		r.atualizarDespesa(2, new Despesa(2,"", "08072010", "07072010", (float) 50.89, "Conta de energia - CELPE"));
		//r.atualizarDespesa(3, new Despesa(3,"", "02082010", "01082010", (float) 88.89, "Conta de agua - COMPESA"));

		//r.removerDespesa(1);
		//r.removerDespesa(2);
		//r.removerDespesa(3);

		*//**Consultar despesas pela data de vencimento**//*

		Vector<Despesa> despesas = r.consultarDespesaPorDataVencimento("10072010");

		for(int i = 0; i < despesas.size(); i++){

			System.out.println("COD. :" + despesas.get(i).getCodigoDespesa() + '\n' + 
							   "CPF ATENDENTE :" + despesas.get(i).getCpf_atendente() + '\n' +
							   "DATA VENCIMENTO :" + despesas.get(i).getDataVencimento() + '\n' +
							   "DATA PAGAMENTO :" + despesas.get(i).getDataPagamento() + '\n' +
							   "VALOR :" + despesas.get(i).getValor() + '\n' + 
							   "EMPRESA BENEFICIADA. :" + despesas.get(i).getEmpresaBeneficiada());
			System.out.println();
		}

		*//**Consultar despesas por empresa beneficiada**//*

		Vector<Despesa> despesas = r.consultarDespesaPorEmpresa("CELPE");

		for(int i = 0; i < despesas.size(); i++){

			System.out.println("COD. :" + despesas.get(i).getCodigoDespesa() + '\n' + 
					"CPF ATENDENTE :" + despesas.get(i).getCpf_atendente() + '\n' +
					"DATA VENCIMENTO :" + despesas.get(i).getDataVencimento() + '\n' +
					"DATA PAGAMENTO :" + despesas.get(i).getDataPagamento() + '\n' +
					"VALOR :" + despesas.get(i).getValor() + '\n' + 
					"EMPRESA BENEFICIADA. :" + despesas.get(i).getEmpresaBeneficiada());
			System.out.println();
		}

		*//**Consultar despesas por Status**//*

		Vector<Despesa> desp = r.consultarDespesaPorStatus("nao");

		for(int i = 0; i < desp.size(); i++){

			System.out.println("COD. :" + desp.get(i).getCodigoDespesa() + '\n' + 
					"CPF ATENDENTE :" + desp.get(i).getCpf_atendente() + '\n' +
					"DATA VENCIMENTO :" + desp.get(i).getDataVencimento() + '\n' +
					"DATA PAGAMENTO :" + desp.get(i).getDataPagamento() + '\n' +
					"VALOR :" + desp.get(i).getValor() + '\n' + 
					"EMPRESA BENEFICIADA. :" + desp.get(i).getEmpresaBeneficiada());
			System.out.println();
		}

	}
*/
}
